@@ -396,6 +396,10 @@ nautilus_icon_info_lookup (GIcon *icon,
 		}
 
 		filename = gtk_icon_info_get_filename (gtkicon_info);
+		if (filename == NULL) {
+			gtk_icon_info_free (gtkicon_info);
+			return nautilus_icon_info_new_for_pixbuf (NULL);
+		}
 
 		lookup_key.filename = (char *)filename;
 		lookup_key.size = size;
@@ -623,60 +627,6 @@ nautilus_get_icon_size_for_zoom_level (NautilusZoomLevel zoom_level)
 	g_return_val_if_reached (NAUTILUS_ICON_SIZE_STANDARD);
 }
 
-float
-nautilus_get_relative_icon_size_for_zoom_level (NautilusZoomLevel zoom_level)
-{
-	return (float)nautilus_get_icon_size_for_zoom_level (zoom_level) / NAUTILUS_ICON_SIZE_STANDARD;
-}
-
-guint
-nautilus_icon_get_larger_icon_size (guint size)
-{
-	if (size < NAUTILUS_ICON_SIZE_SMALLEST) {
-		return NAUTILUS_ICON_SIZE_SMALLEST;
-	}
-	if (size < NAUTILUS_ICON_SIZE_SMALLER) {
-		return NAUTILUS_ICON_SIZE_SMALLER;
-	}
-	if (size < NAUTILUS_ICON_SIZE_SMALL) {
-		return NAUTILUS_ICON_SIZE_SMALL;
-	}
-	if (size < NAUTILUS_ICON_SIZE_STANDARD) {
-		return NAUTILUS_ICON_SIZE_STANDARD;
-	}
-	if (size < NAUTILUS_ICON_SIZE_LARGE) {
-		return NAUTILUS_ICON_SIZE_LARGE;
-	}
-	if (size < NAUTILUS_ICON_SIZE_LARGER) {
-		return NAUTILUS_ICON_SIZE_LARGER;
-	}
-	return NAUTILUS_ICON_SIZE_LARGEST;
-}
-
-guint
-nautilus_icon_get_smaller_icon_size (guint size)
-{
-	if (size > NAUTILUS_ICON_SIZE_LARGEST) {
-		return NAUTILUS_ICON_SIZE_LARGEST;
-	}
-	if (size > NAUTILUS_ICON_SIZE_LARGER) {
-		return NAUTILUS_ICON_SIZE_LARGER;
-	}
-	if (size > NAUTILUS_ICON_SIZE_LARGE) {
-		return NAUTILUS_ICON_SIZE_LARGE;
-	}
-	if (size > NAUTILUS_ICON_SIZE_STANDARD) {
-		return NAUTILUS_ICON_SIZE_STANDARD;
-	}
-	if (size > NAUTILUS_ICON_SIZE_SMALL) {
-		return NAUTILUS_ICON_SIZE_SMALL;
-	}
-	if (size > NAUTILUS_ICON_SIZE_SMALLER) {
-		return NAUTILUS_ICON_SIZE_SMALLER;
-	}
-	return NAUTILUS_ICON_SIZE_SMALLEST;
-}
-
 gint
 nautilus_get_icon_size_for_stock_size (GtkIconSize size)
 {
