@@ -97,6 +97,8 @@ typedef struct {
 	NautilusWindowOpenFlags go_to_after_mount_flags;
 
 	GtkTreePath *eject_highlight_path;
+
+	guint bookmarks_changed_id;
 } NautilusPlacesSidebar;
 
 typedef struct {
@@ -2685,6 +2687,7 @@ bookmarks_button_release_event_cb (GtkWidget *widget,
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 	GtkTreeView *tree_view;
+	gboolean res;
 
 	path = NULL;
 
@@ -2708,8 +2711,12 @@ bookmarks_button_release_event_cb (GtkWidget *widget,
 			return FALSE;
 		}
 
-		gtk_tree_view_get_path_at_pos (tree_view, (int) event->x, (int) event->y,
-					       &path, NULL, NULL, NULL);
+		res = gtk_tree_view_get_path_at_pos (tree_view, (int) event->x, (int) event->y,
+						     &path, NULL, NULL, NULL);
+
+		if (!res) {
+			return FALSE;
+		}
 
 		gtk_tree_model_get_iter (model, &iter, path);
 
@@ -3243,6 +3250,12 @@ nautilus_places_sidebar_dispose (GObject *object)
 		sidebar->eject_highlight_path = NULL;
 	}
 
+	if (sidebar->bookmarks_changed_id != 0) {
+		g_signal_handler_disconnect (sidebar->bookmarks,
+					     sidebar->bookmarks_changed_id);
+		sidebar->bookmarks_changed_id = 0;
+	}
+
 	g_clear_object (&sidebar->store);
 	g_clear_object (&sidebar->volume_monitor);
 	g_clear_object (&sidebar->bookmarks);
@@ -3286,9 +3299,10 @@ nautilus_places_sidebar_set_parent_window (NautilusPlacesSidebar *sidebar,
 	sidebar->bookmarks = nautilus_bookmark_list_new ();
 	sidebar->uri = nautilus_window_slot_get_current_uri (slot);
 
-	g_signal_connect_object (sidebar->bookmarks, "changed",
-				 G_CALLBACK (update_places),
-				 sidebar, G_CONNECT_SWAPPED);
+	sidebar->bookmarks_changed_id =
+		g_signal_connect_swapped (sidebar->bookmarks, "changed",
+					  G_CALLBACK (update_places),
+					  sidebar);
 
 	g_signal_connect_object (window, "loading_uri",
 				 G_CALLBACK (loading_uri_callback),
